@@ -1,3 +1,6 @@
+from typing import Union
+
+from pdlpy.decorators import iterable
 from pdlpy.distribution import Distribution
 from pdlpy.math import floor, ncr
 
@@ -41,7 +44,8 @@ class Binomial(Distribution):
             ")"
         )
 
-    def pmf(self, x: int) -> float:
+    @iterable
+    def pmf(self, x: Union[list, tuple, int]) -> Union[list, tuple, float]:
         """
         Probability Mass Function
 
@@ -57,7 +61,8 @@ class Binomial(Distribution):
 
         return ncr(self._n, x) * self._p**x * (1 - self._p) ** (self._n - x)
 
-    def cdf(self, x: int) -> float:
+    @iterable
+    def cdf(self, x: Union[list, tuple, int]) -> Union[list, tuple, float]:
         """
         Cumulative Distribution Function
 
