@@ -1,3 +1,6 @@
+from typing import Union
+
+from pdlpy.decorators import iterable
 from pdlpy.distribution import Distribution
 from pdlpy.math import e, factorial, floor
 
@@ -35,7 +38,8 @@ class Poisson(Distribution):
             ")"
         )
 
-    def pmf(self, x: int) -> float:
+    @iterable
+    def pmf(self, x: Union[list, tuple, int]) -> Union[list, tuple, float]:
         """
         Probability Mass Function
 
@@ -51,7 +55,8 @@ class Poisson(Distribution):
 
         return (self._r**x) * (e ** (-self._r)) / factorial(x)
 
-    def cdf(self, x: int) -> float:
+    @iterable
+    def cdf(self, x: Union[list, tuple, int]) -> Union[list, tuple, float]:
         """
         Cumulative Distribution Function
 
