@@ -1,3 +1,6 @@
+from typing import Union
+
+from pdlpy.decorators import iterable
 from pdlpy.distribution import Distribution
 
 
@@ -36,7 +39,8 @@ class Uniform(Distribution):
             ")"
         )
 
-    def pdf(self, x: float) -> float:
+    @iterable
+    def pdf(self, x: Union[list, tuple, float]) -> Union[list, tuple, float]:
         """
         Probability Density Function
 
@@ -55,7 +59,8 @@ class Uniform(Distribution):
 
         return 1 / (self._b - self._a)
 
-    def cdf(self, x: float) -> float:
+    @iterable
+    def cdf(self, x: Union[list, tuple, float]) -> Union[list, tuple, float]:
         """
         Cumulative Distribution Function
 
